#    guppy Copyright (C) 2010-2011 guppy team members.
#
#    This program comes with ABSOLUTELY NO WARRANTY; for details type `show w'.
#    This is free software, and you are welcome to redistribute it
#    under certain conditions; type `show c' for details.
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.

import time
import datetime
from datetime import datetime as dt
import os
import sqlite3
import threading
import urllib.request
import xml.etree.ElementTree as ET


@plugin
class Rss(object):
    def __init__(self, server):
        # Variables.
        self.server = server
        self.network = self.server.config["network"]
        self.commands = ["rss-add", "rss-del", "rss-list"]
        self.loop = True
        # self.server.handle("command", self.handle_command, self.commands)
        # Define and/or create database.
        self.db = os.path.join(self.server.config["confdir"],"rss.db")
        self.db_exists = os.path.isfile(self.db)
        self.connection = sqlite3.connect(self.db)
        self.cursor  = self.connection.cursor()
        if (not self.db_exists):
            # create the db
            self.cursor.execute('''CREATE TABLE rss (id text, network text, channel text, url text)''')
            self.connection.commit()
            print("[DEBUG] [rss] Database created for the first time")
            self.cursor.close()
        # Set up the thread to check for new feeds.
        self.timeCheckFeeds = 10;
        def loop(plugin,server):
            timeWaited = 0
            while self.loop:
                if timeWaited >= self.timeCheckFeeds:
                    self.checkFeeds()
                    timeWaited = 0
                time.sleep(10)
                timeWaited += 10
        self.t1 = threading.Thread(target=loop, args=(self,server,))
        self.t1.daemon = True
        self.t1.start()
    def announceFeed(self, row):
        # row = ('1', 'gnu', '#guppy', 'http://phys.org/rss-feed/')
        url = row[3]
        s = urllib.request.urlopen(url)
        s = s.read()
        root = ET.fromstring(s);
        for channel in root:
            for child in channel:
                if (child.tag == 'item'):
                    id = child.find('guid').text
                    if (id == row[0]): return
                    if row[0] == "":
                        # update the db
                        connection = sqlite3.connect(self.db)
                        cursor  = connection.cursor()
                        print('UPDATE rss SET id = %s where network = %s and channel = %s and url = %s'%(id, row[1], row[2], row[3]))
                        cursor.execute("UPDATE rss SET id = ? where network = ? and channel = ? and url = ?", (id, row[1], row[2], row[3]))
                        connection.commit()
                        connection.close()
                    title = child.find('title').text
                    url = child.find('link').text
                    url = urllib.request.urlopen("http://tinyurl.com/api-create.php?url="+url).readline().decode('utf8')
                    cat = child.find('category').text
                    print("%s [%s] %s" % (url, cat, title))
    def checkFeeds(self):
        connection = sqlite3.connect(self.db)
        cursor  = connection.cursor()
        cursor.execute('SELECT * FROM rss')
        print("Got the rows...")
        for row in cursor.fetchmany():
            self.announceFeed(row)
        cursor.close()
